#!/bin/sh
echo 'name: base64-bytestring
version: 0.1.0.3
id: base64-bytestring-0.1.0.3-b0ded2e1421ddfbfbba2f10ec0710fd9

license: BSD3
copyright: 2010 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability:
homepage: https://github.com/bos/base64-bytestring
package-url:
description: Fast base64 encoding and deconding for ByteStrings
category: Data
author: Bryan O'\''Sullivan <bos@serpentine.com>
pkgpath: devel/hs-base64-bytestring
exposed: True
exposed-modules: Data.ByteString.Base64
hidden-modules:
import-dirs: /usr/local/lib/ghc/base64-bytestring-0.1.0.3
library-dirs: /usr/local/lib/ghc/base64-bytestring-0.1.0.3
hs-libraries: HSbase64-bytestring-0.1.0.3
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
         bytestring-0.9.1.10-4e62762ee9b2a5d0cc5bc2fbaaeefd53
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-base64-bytestring-0.1.0.3/html/base64-bytestring.haddock
haddock-html: /usr/local/share/doc/hs-base64-bytestring-0.1.0.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
